ranged

Function ranged 

pub fn ranged<B>(bounds: B) -> BoxGen<f64>
where B: RangeBounds<f64>,
Generator that only return finite numbers in the given range.

This generator has some overweight to special edge case values.

It will throw if any of ±Inf or NaN is part of the given range.