pub fn completely_random<B>(bounds: B) -> BoxGen<u8>where
B: RangeBounds<u8>,Expand description
Int generator with completely random distribution. This
function has a long name, since ranged should be preferred.
pub fn completely_random<B>(bounds: B) -> BoxGen<u8>where
B: RangeBounds<u8>,Int generator with completely random distribution. This
function has a long name, since ranged should be preferred.