pub fn completely_random<B>(bounds: B) -> BoxGen<usize>where
B: RangeBounds<usize>,Expand description
Int generator with completely random distribution. This
function has a long name, since ranged should be preferred.
pub fn completely_random<B>(bounds: B) -> BoxGen<usize>where
B: RangeBounds<usize>,Int generator with completely random distribution. This
function has a long name, since ranged should be preferred.