pub fn filter<E, P>(original_gen: BoxGen<E>, predicate: P) -> BoxGen<E>where E: Clone + 'static, P: Fn(&E) -> bool + Clone + 'static,
Creates a generator that uses the given predicate to determine which examples should be kept and not filtered out.